import { buildProTableDataSource } from '@/utils/antdUtils';
import { PageContainer, ProTable } from '@ant-design/pro-components';
import { Button, Space } from 'antd';
import { useRef } from 'react';
import { Access, useAccess, history } from 'umi';
import moment from 'moment';
import { getList } from './service';

const Account = () => {
    const actionRef = useRef();
    const access = useAccess();
    const formRef = useRef();

    const columns = [
        {
            title: '述求号',
            dataIndex: 'reportUserName',
            order: 8,
        },
        {
            title: '录入人',
            dataIndex: 'reportUserName',
            order: 7,
        },
        {
            title: '录入联系方式',
            dataIndex: 'reportUserPhone',
            order: 6,
        },
        {
            title: '申请人',
            dataIndex: 'name',
            order: 5,
        },
        {
            title: '申请时间',
            dataIndex: 'name',
            hideInTable: true,
            valueType: 'dateRange',
            order: 3,
        },
        {
            title: '审批时间',
            dataIndex: 'name',
            valueType: 'dateRange',
            order: 2,
        },
        {
            title: '审批人',
            dataIndex: 'name',
            order: 4,
        },
        {
            title: '驳回理由',
            dataIndex: 'contactNumber',
            hideInSearch: true,
        },
        {
            title: '状态',
            dataIndex: 'status',
            order: 1,
            valueEnum: {
                0: '正在办理',
                1: '延期办理',
                2: '超时办理',
                3: '已办结',
                4: '上报待审核',
            },
            render: (text, record) => {
                return Number(record.status) == 0 ? '正在办理' : record.status == 1 ? '延期办理' : record.status == 2 ? '超时办理' : record.status == 3 ? '已办结' : record.status == 4 ? '上报待审核' : '已办结';
            }
        },
        {
            title: '操作',
            hideInSearch: true,
            render: (text, record) => {
                return (
                    <Space>
                        {
                            <Access accessible={access['/complaint/detail']}>
                                <Button
                                    type="link"
                                    onClick={() => {
                                        history.push('/appeal-management/detail?id=' + record.id)
                                    }}
                                >
                                    查看详情
                                </Button>
                            </Access>
                        }
                    </Space>
                );
            },
        },
    ];
    return (
        <div>
            <PageContainer header={{
                breadcrumb: {},
            }}
                title={'问题驳回统计'}
            >
                <ProTable
                    rowKey="id"
                    actionRef={actionRef}
                    columns={columns}
                    formRef={formRef}
                    request={async (params) => {

                        if (params.time && params.time.length > 0) {
                            params.startTime = moment(params.time[0]).format('YYYY-MM-DD HH:mm:ss');
                            params.endTime = moment(params.time[1]).format('YYYY-MM-DD 23:59:59');
                            delete params.time
                        } else {
                            delete params.startTime
                            delete params.endTime
                        }


                        return buildProTableDataSource(getList, params);
                    }}
                    search={{ labelWidth: 'auto', defaultCollapsed: false }}
                />
            </PageContainer>
        </div>
    );
};

export default Account;
